summaryrefslogtreecommitdiff
path: root/libnm-util/nm-setting-wireless.c
diff options
context:
space:
mode:
Diffstat (limited to 'libnm-util/nm-setting-wireless.c')
-rw-r--r--libnm-util/nm-setting-wireless.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libnm-util/nm-setting-wireless.c b/libnm-util/nm-setting-wireless.c
index 8c3ea07cc8..c350625ae4 100644
--- a/libnm-util/nm-setting-wireless.c
+++ b/libnm-util/nm-setting-wireless.c
@@ -1221,7 +1221,7 @@ nm_setting_wireless_class_init (NMSettingWirelessClass *setting_class)
* A list of BSSIDs (each BSSID formatted as a MAC address like
* '00:11:22:33:44:55') that have been detected as part of the Wi-FI network.
* NetworkManager internally tracks previously seen BSSIDs. The property is only
* meant for reading and reflects the BBSID list of NetworkManager. The changes you
* make to this property will not be preserved.
**/
g_object_class_install_property
@@ -1233,7 +1233,7 @@ nm_setting_wireless_class_init (NMSettingWirelessClass *setting_class)
"detected as part of the WiFI network. "
"NetworkManager internally tracks previously seen "
"BSSIDs. The property is only meant for reading "
- "and reflects the BBSID list of NetworkManager. "
+ "and reflects the BSSID list of NetworkManager. "
"The changes you make to this property will not be "
"preserved.",
DBUS_TYPE_G_LIST_OF_STRING,
@@ -1221,7 +1221,7 @@ nm_setting_wireless_class_init (NMSettingWirelessClass *setting_class)
* '00:11:22:33:44:55') that have been detected as part of the Wi-FI network.
* NetworkManager internally tracks previously seen BSSIDs. The property is only
- * meant for reading and reflects the BBSID list of NetworkManager. The changes you
+ * meant for reading and reflects the BSSID list of NetworkManager. The changes you
* make to this property will not be preserved.
**/